==> intel-compute-runtime_25.31.34666.3.orig.tar.gz: compute-runtime-25.31.34666.3/level_zero/core/test/unit_tests/sources/mutable_cmdlist/fixtures/mutable_indirect_data_fixture.cpp <==
/*
 * Copyright (C) 2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "level_zero/core/test/unit_tests/sources/mutable_cmdlist/fixtures/mutable_indirect_data_fixture.h"

#include "shared/source/helpers/aligned_memory.h"

namespace L0 {
namespace ult {

void MutableIndirectDataFixture::createMutableIndirectOffset() {
    auto indirectOffsets = std::make_unique<L0::MCL::MutableIndirectData::Offsets>();
    indirectOffsets->globalWorkSize = offsets.globalWorkSize;
    indirectOffsets->localWorkSize = offsets.localWorkSize;
    indirectOffsets->localWorkSize2 = offsets.localWorkSize2;
    indirectOffsets->enqLocalWorkSize = offsets.enqLocalWorkSize;
    indirectOffsets->numWorkGroups = offsets.numWorkGroups;
    indirectOffsets->workDimensions = offsets.workDimensions;
    indirectOffsets->globalWorkOffset = offsets.globalWorkOffset;

    ArrayRef<uint8_t> crossThreadDataRef;
    ArrayRef<uint8_t> perThreadDataRef;
    ArrayRef<uint8_t> inlineDataRef;

    this->crossThreadData = std::unique_ptr<uint8_t, decltype(&alignedFree)>(reinterpret_cast<uint8_t *>(alignedMalloc(this->crossThreadDataSize, 32)), &alignedFree);
    memset(this->crossThreadData.get(), 0, this->crossThreadDataSize);
    crossThreadDataRef = {this->crossThreadData.get(), this->crossThreadDataSize};

    if (this->perThreadDataSize) {
        this->perThreadData = std::unique_ptr<uint8_t, decltype(&alignedFree)>(reinterpret_cast<uint8_t *>(alignedMalloc(this->perThreadDataSize, 32)), &alignedFree);
        memset(this->perThreadData.get(), 0, this->perThreadDataSize);
        perThreadDataRef = {this->perThreadData.get(), this->perThreadDataSize};
    }
    if (this->inlineSize) {
        this->inlineData = std::unique_ptr<uint8_t, decltype(&alignedFree)>(reinterpret_cast<uint8_t *>(alignedMalloc(this->inlineSize, 32)), &alignedFree);
        memset(this->inlineData.get(), 0, this->inlineSize);
        inlineDataRef = {this->inlineData.get(), this->inlineSize};
    }

    this->indirectData = std::make_unique<L0::MCL::MutableIndirectData>(std::move(indirectOffsets), crossThreadDataRef, perThreadDataRef, inlineDataRef);
    this->mockMutableIndirectData = static_cast<MockMutableIndirectData *>(this->indirectData.get());
}

void MutableIndirectDataFixture::recalculateOffsets(L0::MCL::CrossThreadDataOffset initialOffset) {
    offsets.globalWorkSize = initialOffset;
    offsets.localWorkSize = initialOffset + Offsets::patchSize;
    offsets.localWorkSize2 = initialOffset + 2 * Offsets::patchSize;
    offsets.enqLocalWorkSize = initialOffset + 3 * Offsets::patchSize;
    offsets.numWorkGroups = initialOffset + 4 * Offsets::patchSize;
    offsets.workDimensions = initialOffset + 5 * Offsets::patchSize;
    offsets.globalWorkOffset = initialOffset + 6 * Offsets::patchSize;
}

void MutableIndirectDataFixture::undefineOffsets() {
    offsets.globalWorkSize = undefinedOffset;
    offsets.localWorkSize = undefinedOffset;
    offsets.localWorkSize2 = undefinedOffset;
    offsets.enqLocalWorkSize = undefinedOffset;
    offsets.numWorkGroups = undefinedOffset;
    offsets.workDimensions = undefinedOffset;
    offsets.globalWorkOffset = undefinedOffset;
}

} // namespace ult
} // namespace L0

==> intel-compute-runtime_25.48.36300.8.orig.tar.gz: compute-runtime-25.48.36300.8/level_zero/core/test/unit_tests/sources/mutable_cmdlist/fixtures/mutable_indirect_data_fixture.cpp <==
/*
 * Copyright (C) 2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#include "level_zero/core/test/unit_tests/sources/mutable_cmdlist/fixtures/mutable_indirect_data_fixture.h"

#include "shared/source/helpers/aligned_memory.h"

namespace L0 {
namespace ult {

void MutableIndirectDataFixture::createMutableIndirectOffset() {
    auto indirectOffsets = std::make_unique<L0::MCL::MutableIndirectData::Offsets>();

    auto fillOffsets = [](auto &offsets, auto srcOffset, size_t num) {
        for (size_t i = 0; i < num; ++i) {
            offsets[i] = srcOffset + static_cast<decltype(srcOffset)>(i * sizeof(offsets[0]));
        }
    };

    fillOffsets(indirectOffsets->globalWorkSize, offsets.globalWorkSize, 3);
    fillOffsets(indirectOffsets->localWorkSize, offsets.localWorkSize, 3);
    fillOffsets(indirectOffsets->localWorkSize2, offsets.localWorkSize2, 3);
    fillOffsets(indirectOffsets->enqLocalWorkSize, offsets.enqLocalWorkSize, 3);
    fillOffsets(indirectOffsets->numWorkGroups, offsets.numWorkGroups, 3);
    indirectOffsets->workDimensions = offsets.workDimensions;
    fillOffsets(indirectOffsets->globalWorkOffset, offsets.globalWorkOffset, 3);

    ArrayRef<uint8_t> crossThreadDataRef;
    ArrayRef<uint8_t> perThreadDataRef;
    ArrayRef<uint8_t> inlineDataRef;

    this->crossThreadData = std::unique_ptr<uint8_t, decltype(&alignedFree)>(reinterpret_cast<uint8_t *>(alignedMalloc(this->crossThreadDataSize, 32)), &alignedFree);
    memset(this->crossThreadData.get(), 0, this->crossThreadDataSize);
    crossThreadDataRef = {this->crossThreadData.get(), this->crossThreadDataSize};

    if (this->perThreadDataSize) {
        this->perThreadData = std::unique_ptr<uint8_t, decltype(&alignedFree)>(reinterpret_cast<uint8_t *>(alignedMalloc(this->perThreadDataSize, 32)), &alignedFree);
        memset(this->perThreadData.get(), 0, this->perThreadDataSize);
        perThreadDataRef = {this->perThreadData.get(), this->perThreadDataSize};
    }
    if (this->inlineSize) {
        this->inlineData = std::unique_ptr<uint8_t, decltype(&alignedFree)>(reinterpret_cast<uint8_t *>(alignedMalloc(this->inlineSize, 32)), &alignedFree);
        memset(this->inlineData.get(), 0, this->inlineSize);
        inlineDataRef = {this->inlineData.get(), this->inlineSize};
    }

    this->indirectData = std::make_unique<L0::MCL::MutableIndirectData>(std::move(indirectOffsets), crossThreadDataRef, perThreadDataRef, inlineDataRef);
    this->mockMutableIndirectData = static_cast<MockMutableIndirectData *>(this->indirectData.get());
}

void MutableIndirectDataFixture::recalculateOffsets(L0::MCL::CrossThreadDataOffset initialOffset) {
    offsets.globalWorkSize = initialOffset;
    offsets.localWorkSize = initialOffset + Offsets::patchSize;
    offsets.localWorkSize2 = initialOffset + 2 * Offsets::patchSize;
    offsets.enqLocalWorkSize = initialOffset + 3 * Offsets::patchSize;
    offsets.numWorkGroups = initialOffset + 4 * Offsets::patchSize;
    offsets.workDimensions = initialOffset + 5 * Offsets::patchSize;
    offsets.globalWorkOffset = initialOffset + 6 * Offsets::patchSize;
}

void MutableIndirectDataFixture::undefineOffsets() {
    offsets.globalWorkSize = undefinedOffset;
    offsets.localWorkSize = undefinedOffset;
    offsets.localWorkSize2 = undefinedOffset;
    offsets.enqLocalWorkSize = undefinedOffset;
    offsets.numWorkGroups = undefinedOffset;
    offsets.workDimensions = undefinedOffset;
    offsets.globalWorkOffset = undefinedOffset;
}

} // namespace ult
} // namespace L0
